pub fn gather_metadata(file: &EncryptionInputFile) -> FileMetadataExpand description
Collects the metadata to preserve for an input file or directory. Fields that cannot be read (or do not exist on this platform) are simply absent.
pub fn gather_metadata(file: &EncryptionInputFile) -> FileMetadataCollects the metadata to preserve for an input file or directory. Fields that cannot be read (or do not exist on this platform) are simply absent.